@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '1.62';
+$CPAN::Perl::Releases::VERSION = '1.96';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -137,6 +137,24 @@ our $data =
 "5.18.2-RC4" => { id => 'RJBS' },
 "5.18.2" => { id => 'RJBS' },
 "5.19.8" => { id => 'RJBS' },
+"5.19.9" => { id => 'TONYC' },
+"5.19.10" => { id => 'ARC' },
+"5.19.11" => { id => 'SHAY' },
+"5.20.0-RC1" => { id => 'RJBS' },
+"5.20.0" => { id => 'RJBS' },
+"5.21.0" => { id => 'RJBS' },
+"5.21.1" => { id => 'WOLFSAGE' },
+"5.21.2" => { id => 'ABIGAIL' },
+"5.21.3" => { id => 'PCM' },
+"5.20.1-RC1" => { id => 'SHAY' },
+"5.20.1-RC2" => { id => 'SHAY' },
+"5.20.1" => { id => 'SHAY' },
+"5.18.3-RC1" => { id => 'RJBS' },
+"5.21.4" => { id => 'SHAY' },
+"5.18.3-RC2" => { id => 'RJBS' },
+"5.18.3" => { id => 'RJBS' },
+"5.18.4" => { id => 'RJBS' },
+"5.21.5" => { id => 'ABIGAIL' },
 };
 
 sub perl_tarballs {
@@ -193,7 +211,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.62
+version 1.96
 
 =head1 SYNOPSIS
 
